@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 
 use base 'Class::Value';
@@ -58,34 +58,33 @@ Class::Value::Enum - the Value Object design pattern
 None yet. This is an early release; fully functional, but undocumented. The
 next release will have more documentation.
 
+=head1 METHODS
+
+=over 4
+
+
+
+=back
+
 Class::Value::Enum inherits from L<Class::Value>.
 
 The superclass L<Class::Value> defines these methods and functions:
 
-    new(), (""(), (%(), (&(), ()(), (*(), (**(), (+(), (-(), (/(), (<<(),
-    (<=>(), (<>(), (>>(), (^(), (atan2(), (cmp(), (cos(), (exp(), (int(),
-    (log(), (sin(), (sqrt(), (|(), (~(), DEFAULTS(),
-    FIRST_CONSTRUCTOR_ARGS(), MUNGE_CONSTRUCTOR_ARGS(), UNHYGIENIC(),
-    add(), atan2(), bit_and(), bit_not(), bit_or(), bit_shift_left(),
-    bit_shift_right(), bit_xor(), check(), clear_exception_container(),
-    clear_notify_delegate(), comparable(), cos(), divide(), except(),
-    exception_container(), exception_container_clear(), exp(), finally(),
-    get_value(), init(), int(), is_defined(), is_valid(),
-    is_valid_normalized_value(), is_valid_value(), is_well_formed(),
-    is_well_formed_value(), iterate(), log(), modulo(), multiply(),
-    normalize(), notify_delegate(), notify_delegate_clear(), num_cmp(),
-    otherwise(), power(), run_checks(),
+    new(), MUNGE_CONSTRUCTOR_ARGS(), check(), clear_exception_container(),
+    clear_notify_delegate(), comparable(), exception_container(),
+    exception_container_clear(), get_value(), init(), is_defined(),
+    is_valid(), is_valid_normalized_value(), is_valid_value(),
+    is_well_formed(), is_well_formed_value(), normalize(),
+    notify_delegate(), notify_delegate_clear(), run_checks(),
     run_checks_with_exception_container(), send_notify_value_invalid(),
     send_notify_value_normalized(), send_notify_value_not_wellformed(),
-    set_value(), sin(), skip_checks(), skip_dirtying(),
-    skip_normalizations(), sqrt(), str_cmp(), stringify(), subtract(),
-    throw_single_exception(), try(), value(), with()
+    set_value(), skip_checks(), skip_dirtying(), skip_normalizations(),
+    str_cmp(), stringify(), throw_single_exception(), value()
 
 The superclass L<Class::Accessor::Complex> defines these methods and
 functions:
 
-    carp(), cluck(), croak(), flatten(), mk_abstract_accessors(),
-    mk_array_accessors(), mk_boolean_accessors(),
+    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
     mk_class_array_accessors(), mk_class_hash_accessors(),
     mk_class_scalar_accessors(), mk_concat_accessors(),
     mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
@@ -103,13 +102,13 @@ The superclass L<Class::Accessor> defines these methods and functions:
 The superclass L<Class::Accessor::Installer> defines these methods and
 functions:
 
-    install_accessor(), subname()
+    install_accessor()
 
 The superclass L<Class::Accessor::Constructor> defines these methods and
 functions:
 
-    NO_DIRTY(), WITH_DIRTY(), _make_constructor(), mk_constructor(),
-    mk_constructor_with_dirty(), mk_singleton_constructor()
+    _make_constructor(), mk_constructor(), mk_constructor_with_dirty(),
+    mk_singleton_constructor()
 
 The superclass L<Data::Inherited> defines these methods and functions:
 
@@ -118,10 +117,10 @@ The superclass L<Data::Inherited> defines these methods and functions:
 The superclass L<Class::Accessor::Constructor::Base> defines these methods
 and functions:
 
-    HYGIENIC(), STORE(), clear_dirty(), clear_hygienic(),
-    clear_unhygienic(), contains_hygienic(), contains_unhygienic(),
-    delete_hygienic(), delete_unhygienic(), dirty(), dirty_clear(),
-    dirty_set(), elements_hygienic(), elements_unhygienic(), hygienic(),
+    STORE(), clear_dirty(), clear_hygienic(), clear_unhygienic(),
+    contains_hygienic(), contains_unhygienic(), delete_hygienic(),
+    delete_unhygienic(), dirty(), dirty_clear(), dirty_set(),
+    elements_hygienic(), elements_unhygienic(), hygienic(),
     hygienic_clear(), hygienic_contains(), hygienic_delete(),
     hygienic_elements(), hygienic_insert(), hygienic_is_empty(),
     hygienic_size(), insert_hygienic(), insert_unhygienic(),
@@ -135,29 +134,11 @@ The superclass L<Tie::StdHash> defines these methods and functions:
     CLEAR(), DELETE(), EXISTS(), FETCH(), FIRSTKEY(), NEXTKEY(), SCALAR(),
     TIEHASH()
 
-=head1 METHODS
-
-=over 4
-
-
-
-=back
-
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<classvalue> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.04 of L<Class::Value::Enum>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-class-value@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -170,13 +151,13 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
