@@ -6,7 +6,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 
 use base 'Class::Value::Exception::Base';
@@ -42,59 +42,6 @@ Class::Value::Exception - the Value Object design pattern
 None yet. This is an early release; fully functional, but undocumented. The
 next release will have more documentation.
 
-Class::Value::Exception inherits from L<Class::Value::Exception::Base>.
-
-The superclass L<Error::Hierarchy> defines these methods and functions:
-
-    NameSpace_DNS(), NameSpace_OID(), NameSpace_URL(), NameSpace_X500(),
-    _depth_accessor(), _exception_hostname_accessor(),
-    _filename_accessor(), _line_accessor(), _message_accessor(),
-    _package_accessor(), _stacktrace_accessor(), _uuid_accessor(),
-    acknowledged(), acknowledged_clear(), acknowledged_set(), carp(),
-    clear_acknowledged(), clear_is_optional(), comparable(), confess(),
-    croak(), depth(), error_depth(), exception_hostname(), filename(),
-    get_properties(), hostname(), init(), is_optional(),
-    is_optional_clear(), is_optional_set(), line(), message(), package(),
-    properties_as_hash(), set_acknowledged(), set_is_optional(),
-    stacktrace(), stringify(), transmute(), uuid()
-
-The superclass L<Error::Hierarchy::Base> defines these methods and
-functions:
-
-    new(), (""(), ()(), (cmp(), dump_as_yaml(), dump_raw()
-
-The superclass L<Error> defines these methods and functions:
-
-    (0+(), (bool(), _throw_Error_Simple(), associate(), catch(), file(),
-    flush(), import(), object(), prior(), record(), text(), throw(), with()
-
-The superclass L<Data::Inherited> defines these methods and functions:
-
-    every_hash(), every_list(), flush_every_cache_by_key()
-
-The superclass L<Class::Accessor::Complex> defines these methods and
-functions:
-
-    cluck(), flatten(), mk_abstract_accessors(), mk_array_accessors(),
-    mk_boolean_accessors(), mk_class_array_accessors(),
-    mk_class_hash_accessors(), mk_class_scalar_accessors(),
-    mk_concat_accessors(), mk_forward_accessors(), mk_hash_accessors(),
-    mk_integer_accessors(), mk_new(), mk_object_accessors(),
-    mk_scalar_accessors(), mk_set_accessors(), mk_singleton()
-
-The superclass L<Class::Accessor> defines these methods and functions:
-
-    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
-    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
-    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
-    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
-    mk_wo_accessors(), mutator_name_for(), set()
-
-The superclass L<Class::Accessor::Installer> defines these methods and
-functions:
-
-    install_accessor(), subname()
-
 =head1 METHODS
 
 =over 4
@@ -141,21 +88,58 @@ Clears the value.
 
 =back
 
-=head1 TAGS
+Class::Value::Exception inherits from L<Class::Value::Exception::Base>.
 
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<classvalue> tag.
+The superclass L<Error::Hierarchy> defines these methods and functions:
 
-=head1 VERSION 
-                   
-This document describes version 0.04 of L<Class::Value::Exception>.
+    acknowledged(), acknowledged_clear(), acknowledged_set(),
+    clear_acknowledged(), clear_is_optional(), comparable(), error_depth(),
+    get_properties(), init(), is_optional(), is_optional_clear(),
+    is_optional_set(), properties_as_hash(), set_acknowledged(),
+    set_is_optional(), stringify(), transmute()
+
+The superclass L<Error::Hierarchy::Base> defines these methods and
+functions:
+
+    new(), dump_as_yaml(), dump_raw()
+
+The superclass L<Error> defines these methods and functions:
+
+    _throw_Error_Simple(), associate(), catch(), file(), flush(), import(),
+    object(), prior(), record(), text(), throw(), with()
+
+The superclass L<Data::Inherited> defines these methods and functions:
+
+    every_hash(), every_list(), flush_every_cache_by_key()
+
+The superclass L<Class::Accessor::Complex> defines these methods and
+functions:
+
+    mk_abstract_accessors(), mk_array_accessors(), mk_boolean_accessors(),
+    mk_class_array_accessors(), mk_class_hash_accessors(),
+    mk_class_scalar_accessors(), mk_concat_accessors(),
+    mk_forward_accessors(), mk_hash_accessors(), mk_integer_accessors(),
+    mk_new(), mk_object_accessors(), mk_scalar_accessors(),
+    mk_set_accessors(), mk_singleton()
+
+The superclass L<Class::Accessor> defines these methods and functions:
+
+    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
+    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
+    follow_best_practice(), get(), make_accessor(), make_ro_accessor(),
+    make_wo_accessor(), mk_accessors(), mk_ro_accessors(),
+    mk_wo_accessors(), mutator_name_for(), set()
+
+The superclass L<Class::Accessor::Installer> defines these methods and
+functions:
+
+    install_accessor()
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-class-value@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -168,13 +152,13 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2007 by Marcel GrE<uuml>nauer
+Copyright 2004-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
